/*
 ============================================================================
 Name        : MainEta.c
 Author      : Jannes Nys
 Version     : v1.0 November 2016
 Copyright   : 
 Publication : unpublished + eta-MAID
 Description : Photoproduction of a pseudoscalar : gamma + N --> 0- + N'
               Applied to gamma + p --> eta + p
               To change the model, change 'CGLN_Ai'
               The model is based on Regge exchanges  + the MAID solution
 ============================================================================
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <complex.h>    	/* Standard Library of Complex Numbers */

#include <EtaPhotReggeModelAmplitudes.h>

int main(void) {
	// mass = { - , MGAMMA, MP, META, MP}
	double mass[5] = {0.0, 0.0, MP, META, MP};
	
        // Eg to plot
        double Eg = 9.0; // beam energy in the lab = 9 GeV
        double costheta = 0.99; // cos theta of the eta meson in the etaN center of mass system

        // go to s and t
        double W = Eg2W(Eg);
        double s = W*W;
        double t = Cos2T(W, costheta, mass);
        printf("t = %lf \n",t);

        // create a kinematics object
        struct Kin kin;
        kinematics(s, t, mass, &kin);

        // calculate the invariant amplitudes from the model
        double complex Ai[5];
        Regge_Ai(kin, Ai);

        // print it
        printf("Re(A1) = %lf GeV^-2\n", creal(Ai[1]));
        printf("Im(A1) = %lf GeV^-2\n", cimag(Ai[1]));
        
	return EXIT_SUCCESS;
}
